
--[[09-29-2021 (mm-dd-yyyy) version 0.6]]--




function progressBar(w, h, t)
    local bar = t or 0
	UiPush()
		UiAlign("left top")
		UiColor(0, 0, 0, 0.5)
		UiImageBox("ui/common/box-solid-10.png", w, h, 6, 6)
		if bar > 0 then
			UiTranslate(2, 2)
			w = (w-4)*bar
			if w < 12 then w = 12 end
			h = h-4
			UiColor(1,1,1,1)
			UiImageBox("ui/common/box-solid-6.png", w, h, 6, 6)
		end
	UiPop()
end

function DrawSlider(value, length, R, G, B, dotR, dotG, dotB)
    UiPush()
        UiAlign("left middle")
        UiColor(R, G, B)
        UiRect(length+20, 20)
        UiColor(dotR, dotG, dotB)
        slidValue, done = UiSlider("ui/common/box-solid-4.png", x, value, 0, length)
    UiPop()
    return slidValue, done
end

function DrawSliderVirtical(value, length, screenLength, R, G, B, dotR, dotG, dotB)
    UiPush()
        UiScale(1, screenLength/(length+20))
        UiRotate(-90)
        UiAlign("left middle")
        UiColor(R, G, B)
        UiRect(length+20, 20)
        UiColor(dotR, dotG, dotB)
        slidValue, done = UiSlider("pic/ui/slider-vertical.png", x, value, 0, length)
    UiPop()
    return slidValue, done
end

function DrawNormalText(text, font, size, R, G, B)
    local newFont = FontList(font)
    UiPush()
        UiColor(R, G, B)
        UiFont(newFont, size)
        UiText(text)
    UiPop()
end

function DrawValueText(value, text, font, size, R, G, B)
        UiAlign("left")
        UiColor(R, G, B)
        UiFont(font, size)
        UiText(value)
        w, h = UiGetTextSize(value)
        UiTranslate(h+w-18, 0)
        UiText(text)
    UiPop()
end

function DrawColoredTextButtons(condition, text, w, h, font, size, R, G, B)
    local newFont = FontList(font)
    UiPush()
        if condition then
            UiColor(R, G, B)
            UiButtonHoverColor(R*10, G*0.6, B*0.2)
        else
            UiColor(1, 1, 1)
            UiButtonHoverColor(R*0.6, G, B*0.6)
        end
        UiButtonPressDist(3)
        UiFont(newFont, size)
        UiButtonImageBox("ui/common/box-outline-6.png", 6, 6)
        if UiTextButton(text, w, h) then
            condition = not condition
            press = true
        else
            press = false
        end
    UiPop()
    return press, condition
end

function DrawDynamicTextButtons(condition, text1, text2, w, h, font, size, R, G, B)
    local press = false
    UiPush()
        UiButtonPressDist(3)
        UiFont(font, size)
        UiButtonImageBox("ui/common/box-outline-6.png", 6, 6)
        if condition then
            UiColor(R, G, B)
            UiButtonHoverColor(R*10, G*0.6, B*0.2)
            if UiTextButton(text2, w, h) then
                condition = not condition
                press = true
            end
        else
            UiColor(1, 1, 1)
            UiButtonHoverColor(R*0.6, G, B*0.6)
            if UiTextButton(text1, w, h) then
                condition = not condition
                press = true
            end
        end
    UiPop()
    return press, condition
end

function DrawColorPreview(R, G, B)
    UiPush()
        UiColor(R, G, B)
        UiRect(50, 50)
        UiTranslate(130, 0)
    UiPop()
end

function DrawRGBselecter(RGBs, path, branch1, branch2, branch3)
    DrawColorPreview(RGBs[1], RGBs[2], RGBs[3])
    UiTranslate(80, -24)
    UiPush()
        DrawValueText(math.floor(RGBs[1]*256), "", 6, 26, 1, 1, 1)
        UiTranslate(70, 0)
        Rt, rst = DrawSlider(RGBs[1]*256, 256, 0.2, 0.2, 0.2, 1, 0, 0)
        SetFloat(path..branch1, (math.floor(Rt)/256))
    UiPop()
    UiTranslate(0, 40)
    UiPush()
        DrawValueText(math.floor(RGBs[2]*256), "", 6, 26, 1, 1, 1)
        UiTranslate(70, 0)
        Gt, gst = DrawSlider(RGBs[2]*256, 256, 0.2, 0.2, 0.2, 0, 1, 0)
        SetFloat(path..branch2, (math.floor(Gt)/256))
    UiPop()
    UiTranslate(0, 40)
    UiPush()
        DrawValueText(math.floor(RGBs[3]*256), "", 6, 26, 1, 1, 1)
        UiTranslate(70, 0)
        Bt, bst = DrawSlider(RGBs[3]*256, 256, 0.2, 0.2, 0.2, 0, 0, 1)
        SetFloat(path..branch3, (math.floor(Bt)/256))
    UiPop()
end

function scrollAndDrag(windowW, windowH, contentLength, scrollSpeed, adjustFactor, background)

    local length = contentLength or 1
    local inputScrollFactor = scrollSpeed or 1
    local adjust = adjustFactor or 1

    local wheelMove = false
    local wheelMoveTime = 0
    local tempWheel = 0

    UiWindow(windowW, windowH, true)
    UiPush()
        UiTranslate(-1, -1)
        local alpha = background[4]
        if background[4] == nil then alpha = 1 end
        if background[1] > 1 or background[2] > 1 or background[3] > 1 or alpha > 1 then
            if background[4] == nil then alpha = 100 end
            UiColor(background[1]/255, background[2]/255, background[3]/255, alpha/100)
        else
            if background[4] == nil then alpha = 1 end
            UiColor(background[1], background[2], background[3], alpha)
        end
        UiRect(windowW+2, windowH+2)
    UiPop()
    local factor = length*100/(windowH-20)
    if UiIsMouseInRect(windowW, windowH) then
        if InputValue("mousewheel") ~= 0 then
            wheelMove = true
            tempWheel = InputValue("mousewheel")
            wheelMoveTime = GetTime()
        else
            if (GetTime()-wheelMoveTime) > 0.5 then
                wheelMove = false
            end
        end
        if wheelMove then
            SetValue("wheel", tempWheel*inputScrollFactor)
        else
            SetValue("wheel", 0)
        end
    end
    if factor ~= 0 then
        local newslide = slide - wheel*0.3
        SetValue("slide", newslide, linear, 2)
        if slide >= ((windowH-20)/20)*factor then slide = ((windowH-20)/20)*factor end
        if slide <= 0 then slide = 0 end
        UiPush()
            UiTranslate(windowW-10, 0)
            newslide, dragDone = DrawSliderVirtical(slide, ((windowH-20)/20)*factor, windowH, 0.2, 0.2, 0.2, 1, 1, 1)
        UiPop()
        SetValue("slide", newslide, linear, 2)
        if slide >= ((windowH-20)/20)*factor then slide = ((windowH-20)/20)*factor end
        if slide <= 0 then slide = 0 end
    end
    local slideOutput = -slide*adjust
    if factor == 0 then slideOutput = 0 end
    return slideOutput
end