#include "../2610904501/library.lua"
--#include "../Earthquake/library.lua"


function init()
    version = "0.6"
    date = "Sep 29 2021"

    if GetString("savegame.mod.version") == "" then

        SetBool("savegame.mod.autoearthquake", true)
        SetBool("savegame.mod.shake", true)
        SetBool("savegame.mod.fixstrength", false)
        SetBool("savegame.mod.randomeq", true)

        SetFloat("savegame.mod.prob", 10)
        SetInt("savegame.mod.min", 30)
        SetInt("savegame.mod.max", 60)
        SetInt("savegame.mod.range", 30)
        SetInt("savegame.mod.lasttime", 5)
        SetFloat("savegame.mod.strength", 5)

        SetString("savegame.mod.version", "0.6")
    else
    end

    body1 = FindBodies(nil, true)
    body2 = FindBodies(not nil, true)
    bodyAll = {}
    bodyTrans = {}
    bodyShapeList = {}
    time = 0
    starts = false
    ends = false
    showWarning = false

    Earthquake = GetBool("savegame.mod.autoearthquake")
    shake = GetBool("savegame.mod.shake")
    fixStrength = GetBool("savegame.mod.fixstrength")
    randomEQ = GetBool("savegame.mod.randomeq")
    randomEQprob = GetInt("savegame.mod.prob")/100
    minStartTime = GetInt("savegame.mod.min")
    maxStartTime = GetInt("savegame.mod.max")
    lastTime = 5
    
    if fixStrength then
        strength = GetFloat("savegame.mod.strength")
    else
        strength = math.random(1, 10)
    end

    if randomEQ then
        if math.random() >= randomEQprob then
            Earthquake = false
        end
    end

    if Earthquake then

        startTime = math.random(minStartTime, maxStartTime)

        for i=1, #body1 do
            table.insert(bodyAll, body1[i])
        end

        for i=1, #body2 do
            table.insert(bodyAll, body2[i])
        end

        for i=1, #bodyAll do
            local trans = GetBodyTransform(bodyAll[i])
            local shapes = GetBodyShapes(bodyAll[i])
            table.insert(bodyTrans, trans)
            table.insert(bodyShapeList, shapes)
        end
    end
end

function tick(dt)

    if Earthquake then

        time = time + dt

        if startTime-time < 11 and not starts then
            showWarning = true
        else
            showWarning = false
        end
    
        if time >= startTime and not starts then
            for i=1, #bodyAll do
                if GetBodyMass(bodyAll[i]) ~= 0 and not IsBodyActive(bodyAll[i]) then
                    SetBodyVelocity(bodyAll[i], Vec(0, 0, 0))
                end
            end
            starts = true
        elseif starts and time < startTime+lastTime then
            for i=1, #bodyAll do
                if IsBodyJointedToStatic(bodyAll[i]) and GetBodyVehicle(bodyAll[i]) == 0 then
                    local trans = bodyTrans[i]
                    if shake then
                        local newTrans = GetBodyTransform(bodyAll[i])
                        pos = VecAdd(trans.pos, Vec(0, math.sin((time-startTime)*30)*(-strength*0.01), 0))
                        SetBodyTransform(bodyAll[i], Transform(pos, newTrans.rot))
                    end
                    if math.random() > (1-strength*strength*0.01) then
                        local shapes = bodyShapeList[i]
                        local shapeNum = math.random(1, (math.max(1, #shapes)))
                        if not IsShapeBroken(shapes[shapeNum]) then
                            local holeSize = math.random()*strength*strength*0.1
                            if holeSize >= 1 then
                                shapeTrans = GetShapeWorldTransform(shapes[shapeNum])
                                local up = Vec(0, 10, 0)
                                local a = Vec(-10, 0, 0)
                                local d = Vec(10, 0, 0)
                                local w = Vec(0, 0, -10)
                                local s = Vec(0, 0, 10)
                                MakeHole(shapeTrans.pos, holeSize, holeSize*0.8)
                                MakeHole(VecAdd(shapeTrans.pos, up), holeSize, holeSize*0.8)
                                MakeHole(VecAdd(shapeTrans.pos, a), holeSize, holeSize*0.8)
                                MakeHole(VecAdd(shapeTrans.pos, s), holeSize, holeSize*0.8)
                                MakeHole(VecAdd(shapeTrans.pos, d), holeSize, holeSize*0.8)
                                MakeHole(VecAdd(shapeTrans.pos, w), holeSize, holeSize*0.8)
                                table.remove(shapes, shapeNum)
                            end
                        end
                    end
                end
            end
        elseif time >= startTime+lastTime and not ends then
            body1 = FindBodies(nil, true)
            body2 = FindBodies(not nil, true)
    
            for i=1, #body1 do
                if GetBodyMass(body1[i]) ~= 0 and not IsBodyActive(body1[i]) then
                    SetBodyVelocity(body1[i], Vec(0, 0, 0))
                end
            end
    
            for i=1, #body2 do
                if GetBodyMass(body2[i]) ~= 0 and not IsBodyActive(body2[i]) then
                    SetBodyVelocity(body2[i], Vec(0, 0, 0))
                end
            end
            ends = true
        end
    end
end

function draw()
    if showWarning then
        UiPush()
            UiAlign("center middle")
            UiTranslate(UiCenter(), UiMiddle()+200)
            UiFont("bold.ttf", 70)
            UiColor(1, 79/255, 0)
            UiText("Earthquake Coming in "..math.floor(math.max(startTime-time, 0)).." Seconds!!!")
            UiTranslate(0, 80)
            UiText("Estimated Strength: "..strength)
        UiPop()
    end
end